@@ -16,16 +16,33 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
-ggVAT <- function(x, ...) {
+#' @rdname VAT
+#' @export
+ggVAT <- function(x,
+  upper_tri = TRUE,
+  lower_tri = TRUE,
+  ...) {
   if (!inherits(x, "dist"))
     stop("x needs to be of class 'dist'!")
-  ggpimage(x, seriate(x, "VAT"), ...)
+  ggpimage(x,
+    seriate(x, "VAT"),
+    upper_tri = upper_tri,
+    lower_tri = lower_tri,
+    ...)
 }
 
-ggiVAT <- function(x, ...) {
+#' @rdname VAT
+#' @export
+ggiVAT <- function(x,
+  upper_tri = TRUE,
+  lower_tri = TRUE,
+  ...) {
   if (!inherits(x, "dist"))
     stop("x needs to be of class 'dist'!")
   x <- path_dist(x)
-  ggpimage(x, seriate(x, "VAT"), ...)
+  ggpimage(x,
+    seriate(x, "VAT"),
+    upper_tri = upper_tri,
+    lower_tri = lower_tri,
+    ...)
 }
